Introduce linaro_hikey960-userdebug build target

Add linaro_hikey960-userdebug build target hosted on
source.devboardsforandroid.linaro.org and synced as
device/linaro/hikey960* projects from a local manifest.

Change-Id: I75eebe494376a18b0887861d1aaf397f72bd21a6
Signed-off-by: Amit Pundir <amit.pundir@linaro.org>
diff --git a/Android.bp b/Android.bp
index 1285317..f61a7d8 100644
--- a/Android.bp
+++ b/Android.bp
@@ -14,7 +14,7 @@
 // limitations under the License.
 
 package {
-    default_applicable_licenses: ["device_linaro_hikey_license"],
+    default_applicable_licenses: ["device_linaro_hikey960_license"],
 }
 
 // Added automatically by a large-scale-change that took the approach of
@@ -32,7 +32,7 @@
 // used in the current project.
 // See: http://go/android-license-faq
 license {
-    name: "device_linaro_hikey_license",
+    name: "device_linaro_hikey960_license",
     visibility: [":__subpackages__"],
     license_kinds: [
         "SPDX-license-identifier-Apache-2.0",
diff --git a/Android.mk b/Android.mk
index 41d191f..91436a2 100644
--- a/Android.mk
+++ b/Android.mk
@@ -20,19 +20,19 @@
 # to only building on ARM if they include assembly. Individual makefiles
 # are responsible for having their own logic, for fine-grained control.
 
-ifneq ($(filter hikey%, $(TARGET_DEVICE)),)
+ifneq ($(filter linaro_hikey960, $(TARGET_DEVICE)),)
 
 LOCAL_PATH := $(call my-dir)
 
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,.conf))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,.img))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,.kl))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,.rc))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,.xml))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,fstab.hikey))
-$(eval $(call declare-1p-copy-files,device/linaro/hikey,fstab.hikey960))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,.conf))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,.img))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,.kl))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,.rc))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,.xml))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,fstab.hikey))
+$(eval $(call declare-1p-copy-files,device/linaro/hikey960,fstab.hikey960))
 
-$(eval $(call declare-copy-files-license-metadata,device/linaro/hikey/bt-wifi-firmware-util,,SPDX-license-identifier-BSD,notice,device/linaro/hikey/bt-wifi-firmware-util/NOTICE,))
+$(eval $(call declare-copy-files-license-metadata,device/linaro/hikey960/bt-wifi-firmware-util,,SPDX-license-identifier-BSD,notice,device/linaro/hikey960/bt-wifi-firmware-util/NOTICE,))
 
 # if some modules are built directly from this directory (not subdirectories),
 # their rules should be written here.
diff --git a/AndroidProducts.mk b/AndroidProducts.mk
index 7d7ab60..dca6c8d 100644
--- a/AndroidProducts.mk
+++ b/AndroidProducts.mk
@@ -10,7 +10,7 @@
 #
 
 PRODUCT_MAKEFILES := \
-    $(LOCAL_DIR)/hikey960.mk
+    $(LOCAL_DIR)/linaro_hikey960.mk
 
 COMMON_LUNCH_CHOICES := \
-    hikey960-userdebug
+    linaro_hikey960-userdebug
diff --git a/BoardConfigCommon.mk b/BoardConfigCommon.mk
index c724c7d..033da37 100644
--- a/BoardConfigCommon.mk
+++ b/BoardConfigCommon.mk
@@ -37,15 +37,15 @@
 
 TARGET_USES_HWC2 := true
 
-BOARD_SEPOLICY_DIRS += device/linaro/hikey/sepolicy
+BOARD_SEPOLICY_DIRS += device/linaro/hikey960/sepolicy
 BOARD_SEPOLICY_DIRS += system/bt/vendor_libs/linux/sepolicy
 
-DEVICE_MANIFEST_FILE := device/linaro/hikey/manifest.xml
-DEVICE_MATRIX_FILE := device/linaro/hikey/compatibility_matrix.xml
+DEVICE_MANIFEST_FILE := device/linaro/hikey960/manifest.xml
+DEVICE_MATRIX_FILE := device/linaro/hikey960/compatibility_matrix.xml
 
 ifneq ($(TARGET_SENSOR_MEZZANINE),)
-DEVICE_MANIFEST_FILE += device/linaro/hikey/sensorhal/manifest.xml
-DEVICE_MANIFEST_FILE += device/linaro/hikey/vr/manifest.xml
+DEVICE_MANIFEST_FILE += device/linaro/hikey960/sensorhal/manifest.xml
+DEVICE_MANIFEST_FILE += device/linaro/hikey960/vr/manifest.xml
 endif
 
 ifeq ($(HOST_OS), linux)
@@ -55,4 +55,4 @@
 endif
 
 TARGET_RECOVERY_PIXEL_FORMAT := BGRA_8888
-TARGET_RECOVERY_UI_LIB := librecovery_ui_hikey
+TARGET_RECOVERY_UI_LIB := librecovery_ui_hikey960
diff --git a/build/tasks/dtimage.mk b/build/tasks/dtimage.mk
index 2e480df..5c5851b 100644
--- a/build/tasks/dtimage.mk
+++ b/build/tasks/dtimage.mk
@@ -1,7 +1,7 @@
-ifneq ($(filter hikey%, $(TARGET_DEVICE)),)
+ifneq ($(filter linaro_hikey960, $(TARGET_DEVICE)),)
 ifneq ($(TARGET_NO_DTIMAGE), true)
 
-MKDTIMG := device/linaro/hikey/installer/hikey960/mkdtimg
+MKDTIMG := device/linaro/hikey960/installer/hikey960/mkdtimg
 DTB := $(PRODUCT_OUT)/hi3660-hikey960.dtb
 
 $(PRODUCT_OUT)/dt.img: $(DTB)
diff --git a/device-common.mk b/device-common.mk
index f3ddd56..51b29ad 100644
--- a/device-common.mk
+++ b/device-common.mk
@@ -23,7 +23,7 @@
 $(call inherit-product, $(SRC_TARGET_DIR)/product/full_base.mk)
 
 # Set vendor kernel path
-PRODUCT_VENDOR_KERNEL_HEADERS := device/linaro/hikey/kernel-headers
+PRODUCT_VENDOR_KERNEL_HEADERS := device/linaro/hikey960/kernel-headers
 
 PRODUCT_SHIPPING_API_LEVEL := 31
 PRODUCT_OTA_ENFORCE_VINTF_KERNEL_REQUIREMENTS := false
@@ -33,7 +33,7 @@
 $(call inherit-product, $(SRC_TARGET_DIR)/product/emulated_storage.mk)
 
 # Set custom settings
-DEVICE_PACKAGE_OVERLAYS := device/linaro/hikey/overlay
+DEVICE_PACKAGE_OVERLAYS := device/linaro/hikey960/overlay
 
 #avoid usb crash
 PRODUCT_PRODUCT_PROPERTIES += \
@@ -126,7 +126,7 @@
 PRODUCT_PACKAGES += stm32_flash nanoapp_cmd nanotool
 
 PRODUCT_COPY_FILES += \
-    device/linaro/hikey/init.common.nanohub.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.nanohub.rc
+    device/linaro/hikey960/init.common.nanohub.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.nanohub.rc
 
 # Copy sensors config file(s)
 PRODUCT_COPY_FILES += \
@@ -166,8 +166,8 @@
 
 # Copy hardware config file(s)
 PRODUCT_COPY_FILES +=  \
-        device/linaro/hikey/etc/permissions/android.hardware.screen.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.screen.xml \
-        device/linaro/hikey/etc/permissions/android.software.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.software.xml \
+        device/linaro/hikey960/etc/permissions/android.hardware.screen.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.screen.xml \
+        device/linaro/hikey960/etc/permissions/android.software.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.software.xml \
         frameworks/native/data/etc/android.software.cts.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.software.cts.xml \
         frameworks/native/data/etc/android.software.app_widgets.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.software.app_widgets.xml \
         frameworks/native/data/etc/android.software.backup.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.software.backup.xml \
@@ -182,15 +182,15 @@
         frameworks/native/data/etc/android.hardware.wifi.direct.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.wifi.direct.xml \
         frameworks/native/data/etc/android.hardware.bluetooth.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.bluetooth.xml \
         frameworks/native/data/etc/android.hardware.bluetooth_le.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.bluetooth_le.xml \
-        device/linaro/hikey/wpa_supplicant.conf:$(TARGET_COPY_OUT_VENDOR)/etc/wifi/wpa_supplicant.conf \
+        device/linaro/hikey960/wpa_supplicant.conf:$(TARGET_COPY_OUT_VENDOR)/etc/wifi/wpa_supplicant.conf \
         $(LOCAL_PATH)/wpa_supplicant_overlay.conf:$(TARGET_COPY_OUT_VENDOR)/etc/wifi/wpa_supplicant_overlay.conf \
         $(LOCAL_PATH)/p2p_supplicant_overlay.conf:$(TARGET_COPY_OUT_VENDOR)/etc/wifi/p2p_supplicant_overlay.conf
 
 # audio policy configuration
 USE_XML_AUDIO_POLICY_CONF := 1
 PRODUCT_COPY_FILES += \
-    device/linaro/hikey/audio/audio_policy_configuration.xml:$(TARGET_COPY_OUT_VENDOR)/etc/audio_policy_configuration.xml \
-    device/linaro/hikey/audio/audio_policy_configuration_bluetooth_legacy_hal.xml:$(TARGET_COPY_OUT_VENDOR)/etc/audio_policy_configuration_bluetooth_legacy_hal.xml \
+    device/linaro/hikey960/audio/audio_policy_configuration.xml:$(TARGET_COPY_OUT_VENDOR)/etc/audio_policy_configuration.xml \
+    device/linaro/hikey960/audio/audio_policy_configuration_bluetooth_legacy_hal.xml:$(TARGET_COPY_OUT_VENDOR)/etc/audio_policy_configuration_bluetooth_legacy_hal.xml \
     frameworks/av/services/audiopolicy/config/a2dp_audio_policy_configuration.xml:$(TARGET_COPY_OUT_VENDOR)/etc/a2dp_audio_policy_configuration.xml \
     frameworks/av/services/audiopolicy/config/a2dp_in_audio_policy_configuration_7_0.xml:$(TARGET_COPY_OUT_VENDOR)/etc/a2dp_in_audio_policy_configuration_7_0.xml \
     frameworks/av/services/audiopolicy/config/bluetooth_audio_policy_configuration_7_0.xml:$(TARGET_COPY_OUT_VENDOR)/etc/bluetooth_audio_policy_configuration_7_0.xml \
@@ -201,11 +201,11 @@
 
 # Copy media codecs config file
 PRODUCT_COPY_FILES += \
-        device/linaro/hikey/etc/media_codecs.xml:$(TARGET_COPY_OUT_VENDOR)/etc/media_codecs.xml \
+        device/linaro/hikey960/etc/media_codecs.xml:$(TARGET_COPY_OUT_VENDOR)/etc/media_codecs.xml \
         frameworks/av/media/libstagefright/data/media_codecs_google_audio.xml:$(TARGET_COPY_OUT_VENDOR)/etc/media_codecs_google_audio.xml
 
 PRODUCT_COPY_FILES += \
-    device/linaro/hikey/init.common.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.common.rc \
+    device/linaro/hikey960/init.common.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.common.rc \
 
 
 # Health
diff --git a/factory-images/README b/factory-images/README
index aaa1fb0..6fe8684 100644
--- a/factory-images/README
+++ b/factory-images/README
@@ -4,9 +4,9 @@
 
 $ make -j24  dist
 $ cd out/dist/
-$ . ../../device/linaro/hikey/factory-images/generate-factory-images-package.sh
+$ . ../../device/linaro/hikey960/factory-images/generate-factory-images-package.sh
 
 # Package with an existing image
 # First download the image to the android build top directory
 
-$ device/linaro/hikey/factory-images/generate-factory-images-package.sh
+$ device/linaro/hikey960/factory-images/generate-factory-images-package.sh
diff --git a/factory-images/generate-factory-images-hikey.sh b/factory-images/generate-factory-images-hikey.sh
index 001c0f5..87f832b 100755
--- a/factory-images/generate-factory-images-hikey.sh
+++ b/factory-images/generate-factory-images-hikey.sh
@@ -13,7 +13,7 @@
 # limitations under the License.
 
 
-DEVICE_DIR=device/linaro/hikey/
+DEVICE_DIR=device/linaro/hikey960/
 DEVICE=hikey
 PRODUCT=hikey
 
diff --git a/factory-images/generate-factory-images-hikey960.sh b/factory-images/generate-factory-images-hikey960.sh
index 30cd7b8..73a391d 100755
--- a/factory-images/generate-factory-images-hikey960.sh
+++ b/factory-images/generate-factory-images-hikey960.sh
@@ -13,7 +13,7 @@
 # limitations under the License.
 
 
-DEVICE_DIR=device/linaro/hikey/
+DEVICE_DIR=device/linaro/hikey960/
 DEVICE=hikey960
 PRODUCT=hikey960
 
diff --git a/factory-images/generate-factory-images-package.sh b/factory-images/generate-factory-images-package.sh
index 7a51f7f..443c44b 100755
--- a/factory-images/generate-factory-images-package.sh
+++ b/factory-images/generate-factory-images-package.sh
@@ -16,4 +16,4 @@
 
 source $ANDROID_BUILD_TOP/device/common/clear-factory-images-variables.sh
 # HiKey unfortunately can't use the ./generate-factory-images-common.sh script
-source $ANDROID_BUILD_TOP/device/linaro/hikey/factory-images/generate-factory-images-$TARGET_PRODUCT.sh
+source $ANDROID_BUILD_TOP/device/linaro/hikey960/factory-images/generate-factory-images-$TARGET_PRODUCT.sh
diff --git a/gralloc960/Android.bp b/gralloc960/Android.bp
index 6939a52..735e4c9 100644
--- a/gralloc960/Android.bp
+++ b/gralloc960/Android.bp
@@ -1,15 +1,15 @@
 package {
     // See: http://go/android-license-faq
     // A large-scale-change added 'default_applicable_licenses' to import
-    // all of the 'license_kinds' from "device_linaro_hikey_license"
+    // all of the 'license_kinds' from "device_linaro_hikey960_license"
     // to get the below license kinds:
     //   SPDX-license-identifier-Apache-2.0
     //   SPDX-license-identifier-GPL-2.0
-    default_applicable_licenses: ["device_linaro_hikey_license"],
+    default_applicable_licenses: ["device_linaro_hikey960_license"],
 }
 
 cc_library_shared {
-    name: "hwcomposer.drm_hikey960",
+    name: "hwcomposer.drm_linaro_hikey960",
     defaults: ["hwcomposer.drm_defaults"],
     srcs: [
         ":drm_hwcomposer_common",
diff --git a/hikey960.mk b/linaro_hikey960.mk
similarity index 82%
rename from hikey960.mk
rename to linaro_hikey960.mk
index 1c6ac7b..d04f154 100644
--- a/hikey960.mk
+++ b/linaro_hikey960.mk
@@ -1,7 +1,7 @@
 ifndef TARGET_KERNEL_USE
 TARGET_KERNEL_USE=5.10
 endif
-LOCAL_KERNEL_HOME ?= device/linaro/hikey-kernel/hikey960/$(TARGET_KERNEL_USE)
+LOCAL_KERNEL_HOME ?= device/linaro/hikey960-kernel/$(TARGET_KERNEL_USE)
 TARGET_PREBUILT_KERNEL := $(LOCAL_KERNEL_HOME)/Image.gz-dtb
 TARGET_PREBUILT_DTB := $(LOCAL_KERNEL_HOME)/hi3660-hikey960.dtb
 
@@ -23,8 +23,8 @@
 
 # Inherit the common device configuration
 $(call inherit-product, $(SRC_TARGET_DIR)/product/core_64_bit.mk)
-$(call inherit-product, device/linaro/hikey/hikey960/device-hikey960.mk)
-$(call inherit-product, device/linaro/hikey/device-common.mk)
+$(call inherit-product, device/linaro/hikey960/linaro_hikey960/device-hikey960.mk)
+$(call inherit-product, device/linaro/hikey960/device-common.mk)
 
 PRODUCT_PROPERTY_OVERRIDES += \
   ro.opengles.version=196608 \
@@ -32,10 +32,10 @@
 
 #
 # Overrides
-PRODUCT_NAME := hikey960
-PRODUCT_DEVICE := hikey960
+PRODUCT_NAME := linaro_hikey960
+PRODUCT_DEVICE := linaro_hikey960
 PRODUCT_BRAND := Android
-PRODUCT_MODEL := AOSP on hikey960
+PRODUCT_MODEL := AOSP fork on hikey960
 
 ifneq ($(HIKEY_USES_GKI),)
   HIKEY_MOD_DIR := $(LOCAL_KERNEL_HOME)
@@ -59,4 +59,4 @@
 endif
 
 PRODUCT_SOONG_NAMESPACES += \
-  device/linaro/hikey/mali/bifrost
+  device/linaro/hikey960/mali/bifrost
diff --git a/hikey960/BoardConfig.mk b/linaro_hikey960/BoardConfig.mk
similarity index 92%
rename from hikey960/BoardConfig.mk
rename to linaro_hikey960/BoardConfig.mk
index 6d7b023..ff9c96f 100644
--- a/hikey960/BoardConfig.mk
+++ b/linaro_hikey960/BoardConfig.mk
@@ -1,4 +1,4 @@
-include device/linaro/hikey/BoardConfigCommon.mk
+include device/linaro/hikey960/BoardConfigCommon.mk
 
 TARGET_BOOTLOADER_BOARD_NAME := hikey960
 TARGET_BOARD_PLATFORM := hikey960
@@ -46,4 +46,4 @@
 BOARD_SUPER_PARTITION_METADATA_DEVICE := super
 BOARD_SUPER_IMAGE_IN_UPDATE_PACKAGE := true
 
-TARGET_RECOVERY_FSTAB := device/linaro/hikey/hikey960/fstab.hikey960
+TARGET_RECOVERY_FSTAB := device/linaro/hikey960/linaro_hikey960/fstab.hikey960
diff --git a/hikey960/README b/linaro_hikey960/README
similarity index 97%
rename from hikey960/README
rename to linaro_hikey960/README
index 0418d46..1b0d234 100644
--- a/hikey960/README
+++ b/linaro_hikey960/README
@@ -16,7 +16,7 @@
 
 * Flashing images:
 Enter fastboot mode by turning ON switch 1 and 3
-$ cd device/linaro/hikey/installer/hikey960
+$ cd device/linaro/hikey960/installer/hikey960
 $ ./flash-all.sh
  or
 $ fastboot flash boot out/target/product/hikey960/boot.img
diff --git a/hikey960/board-info.txt b/linaro_hikey960/board-info.txt
similarity index 100%
rename from hikey960/board-info.txt
rename to linaro_hikey960/board-info.txt
diff --git a/hikey960/device-hikey960.mk b/linaro_hikey960/device-hikey960.mk
similarity index 71%
rename from hikey960/device-hikey960.mk
rename to linaro_hikey960/device-hikey960.mk
index ed7f6f4..3d98f34 100644
--- a/hikey960/device-hikey960.mk
+++ b/linaro_hikey960/device-hikey960.mk
@@ -33,12 +33,12 @@
 PRODUCT_COPY_FILES +=	$(TARGET_PREBUILT_KERNEL):kernel \
 			$(TARGET_PREBUILT_DTB):hi3660-hikey960.dtb
 
-PRODUCT_COPY_FILES +=	$(LOCAL_PATH)/fstab.hikey960:$(TARGET_COPY_OUT_VENDOR)/etc/fstab.hikey960 \
-			$(LOCAL_PATH)/fstab.hikey960:$(TARGET_COPY_OUT_RAMDISK)/fstab.hikey960 \
-			device/linaro/hikey/hikey960/init.hikey960.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.rc \
-			device/linaro/hikey/init.hikey960.power.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.power.rc \
-			device/linaro/hikey/hikey960/init.hikey960.usb.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.usb.rc \
-			device/linaro/hikey/ueventd.common.rc:$(TARGET_COPY_OUT_VENDOR)/ueventd.rc \
+PRODUCT_COPY_FILES +=	device/linaro/hikey960/linaro_hikey960/fstab.hikey960:$(TARGET_COPY_OUT_VENDOR)/etc/fstab.hikey960 \
+			device/linaro/hikey960/linaro_hikey960/fstab.hikey960:$(TARGET_COPY_OUT_RAMDISK)/fstab.hikey960 \
+			device/linaro/hikey960/linaro_hikey960/init.hikey960.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.rc \
+			device/linaro/hikey960/init.hikey960.power.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.power.rc \
+			device/linaro/hikey960/linaro_hikey960/init.hikey960.usb.rc:$(TARGET_COPY_OUT_VENDOR)/etc/init/init.hikey960.usb.rc \
+			device/linaro/hikey960/ueventd.common.rc:$(TARGET_COPY_OUT_VENDOR)/ueventd.rc \
 			frameworks/base/data/keyboards/Generic.kl:$(TARGET_COPY_OUT_VENDOR)/usr/keylayout/hikey960.kl \
 			frameworks/native/data/etc/android.hardware.vulkan.level-1.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.vulkan.level.xml \
 			frameworks/native/data/etc/android.hardware.vulkan.version-1_0_3.xml:$(TARGET_COPY_OUT_VENDOR)/etc/permissions/android.hardware.vulkan.version.xml \
@@ -50,12 +50,12 @@
 
 # Copy BT firmware
 PRODUCT_COPY_FILES += \
-	device/linaro/hikey/bt-wifi-firmware-util/TIInit_11.8.32-pcm-960.bts:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/TIInit_11.8.32.bts
+	device/linaro/hikey960/bt-wifi-firmware-util/TIInit_11.8.32-pcm-960.bts:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/TIInit_11.8.32.bts
 
 # Copy wlan firmware
 PRODUCT_COPY_FILES += \
-	device/linaro/hikey/bt-wifi-firmware-util/wl18xx-fw-4.bin:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/wl18xx-fw-4.bin \
-	device/linaro/hikey/bt-wifi-firmware-util/wl18xx-conf-wl1837mod.bin:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/wl18xx-conf.bin
+	device/linaro/hikey960/bt-wifi-firmware-util/wl18xx-fw-4.bin:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/wl18xx-fw-4.bin \
+	device/linaro/hikey960/bt-wifi-firmware-util/wl18xx-conf-wl1837mod.bin:$(TARGET_COPY_OUT_VENDOR)/firmware/ti-connectivity/wl18xx-conf.bin
 
 # Build HiKey960 HDMI audio HAL. Experimental only may not work. FIXME
 PRODUCT_PACKAGES += audio.primary.hikey960
@@ -89,9 +89,9 @@
 
 PRODUCT_PACKAGES += sensors.hikey960
 
-PRODUCT_PACKAGES += hwcomposer.drm_hikey960
+PRODUCT_PACKAGES += hwcomposer.drm_linaro_hikey960
 
 ifneq ($(TARGET_NO_RECOVERY),true)
 PRODUCT_COPY_FILES += \
-	device/linaro/hikey/init.recovery.common.rc:recovery/root/init.recovery.hikey960.rc
+	device/linaro/hikey960/init.recovery.common.rc:recovery/root/init.recovery.hikey960.rc
 endif
diff --git a/hikey960/fstab.hikey960 b/linaro_hikey960/fstab.hikey960
similarity index 100%
rename from hikey960/fstab.hikey960
rename to linaro_hikey960/fstab.hikey960
diff --git a/hikey960/init.hikey960.rc b/linaro_hikey960/init.hikey960.rc
similarity index 78%
rename from hikey960/init.hikey960.rc
rename to linaro_hikey960/init.hikey960.rc
index 92c1385..b21533e 100644
--- a/hikey960/init.hikey960.rc
+++ b/linaro_hikey960/init.hikey960.rc
@@ -5,7 +5,7 @@
 
 on post-fs
     # Set supported opengles version
-    setprop ro.hardware.hwcomposer drm_hikey960
+    setprop ro.hardware.hwcomposer drm_linaro_hikey960
 
 on late-fs
     mount_all /vendor/etc/fstab.${ro.hardware} --late
diff --git a/hikey960/init.hikey960.usb.rc b/linaro_hikey960/init.hikey960.usb.rc
similarity index 100%
rename from hikey960/init.hikey960.usb.rc
rename to linaro_hikey960/init.hikey960.usb.rc
diff --git a/recovery/Android.bp b/recovery/Android.bp
index c4b8df0..4f44dd4 100644
--- a/recovery/Android.bp
+++ b/recovery/Android.bp
@@ -17,14 +17,14 @@
 package {
     // See: http://go/android-license-faq
     // A large-scale-change added 'default_applicable_licenses' to import
-    // all of the 'license_kinds' from "device_linaro_hikey_license"
+    // all of the 'license_kinds' from "device_linaro_hikey960_license"
     // to get the below license kinds:
     //   SPDX-license-identifier-Apache-2.0
-    default_applicable_licenses: ["device_linaro_hikey_license"],
+    default_applicable_licenses: ["device_linaro_hikey960_license"],
 }
 
 cc_library_static {
-    name: "librecovery_ui_hikey",
+    name: "librecovery_ui_hikey960",
     owner: "linaro",
     cflags: [
         "-Wall",
diff --git a/installer/hikey960/flash-all.sh b/installer/hikey960/flash-all.sh
index 70bb432..6b6b56b 100755
--- a/installer/hikey960/flash-all.sh
+++ b/installer/hikey960/flash-all.sh
@@ -3,10 +3,10 @@
 INSTALLER_DIR="`dirname ${0}`"
 ECHO_PREFIX="=== "
 
 # for cases that don't run "lunch hikey960-userdebug"
 if [ -z "${ANDROID_BUILD_TOP}" ]; then
     ANDROID_BUILD_TOP=${INSTALLER_DIR}/../../../../../
-    ANDROID_PRODUCT_OUT="${ANDROID_BUILD_TOP}/out/target/product/hikey960"
+    ANDROID_PRODUCT_OUT="${ANDROID_BUILD_TOP}/out/target/product/linaro_hikey960"
 fi
 
 if [ ! -d "${ANDROID_PRODUCT_OUT}" ]; then
@@ -3,10 +3,10 @@
 ECHO_PREFIX="=== "
 
-# for cases that don't run "lunch hikey960-userdebug"
+# for cases that don't run "lunch linaro_hikey960-userdebug"
 if [ -z "${ANDROID_BUILD_TOP}" ]; then
     ANDROID_BUILD_TOP=${INSTALLER_DIR}/../../../../../
diff --git a/installer/hikey960/legacy-flash-all.sh b/installer/hikey960/legacy-flash-all.sh
index 3f8bf9b..5acac6f 100755
--- a/installer/hikey960/legacy-flash-all.sh
+++ b/installer/hikey960/legacy-flash-all.sh
@@ -2,10 +2,10 @@
 
 INSTALLER_DIR="`dirname ${0}`"
 
 # for cases that don't run "lunch hikey960-userdebug"
 if [ -z "${ANDROID_BUILD_TOP}" ]; then
     ANDROID_BUILD_TOP=${INSTALLER_DIR}/../../../../../
-    ANDROID_PRODUCT_OUT="${ANDROID_BUILD_TOP}/out/target/product/hikey960"
+    ANDROID_PRODUCT_OUT="${ANDROID_BUILD_TOP}/out/target/product/linaro_hikey960"
 fi
 
 if [ ! -d "${ANDROID_PRODUCT_OUT}" ]; then
@@ -2,10 +2,10 @@
 INSTALLER_DIR="`dirname ${0}`"
 
-# for cases that don't run "lunch hikey960-userdebug"
+# for cases that don't run "lunch linaro_hikey960-userdebug"
 if [ -z "${ANDROID_BUILD_TOP}" ]; then
     ANDROID_BUILD_TOP=${INSTALLER_DIR}/../../../../../